Learn R Programming

cbsem (version 1.0.0)

gscalsout: Output of gscals for the simplemodel data.

Description

A list containing the result of gscals for the simplemodel data.

Usage

gscalsout

Arguments

Format

A list with entries:

$Bhat

estimated esign matrix of the simple model

$What

matrix of weights

$lambdahat

mvector of estimated loadings

$iter

number of iterations

$fehl

maximal difference of parameter estimates for the last and second last iteration

$composit

data matrix of composites

$resid

data matrix of residuals of the structural model

$S

Covariance matrix of manifest variables

$ziel

sum of squared residuals for the final sum

$fi

The value of the fit criterion

$R2

vector with the coefficients of determination for structural regressions