Learn R Programming

cbsem (version 1.0.0)

gscmcovout: Output of covgscmodel for the simplemodel data.

Description

A list containing the result of gscmcov for the simplemodel data.

Usage

gscmcovout

Arguments

Format

A list with entries:

$S

Covariance matrix of manifest variables

$B

Design matrix of the simple model

$Scomp

Covariance matrix of composites

$wx

weighting vector for exogenous composites

$wy

weighting vector for endogenous composites

$Sdd

diagonal covariance matrix of errors for loadings of X-variables

$See

diagonal covariance matrix of errors for loadings of Y-variables