A list containing the result of gscmcov for the simplemodel data.
gscmcovoutA list with entries:
Covariance matrix of manifest variables
Design matrix of the simple model
Covariance matrix of composites
weighting vector for exogenous composites
weighting vector for endogenous composites
diagonal covariance matrix of errors for loadings of X-variables
diagonal covariance matrix of errors for loadings of Y-variables